pynrc.detops.det\_timing
========================

.. currentmodule:: pynrc.detops

.. autoclass:: det_timing
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~det_timing.__init__
      ~det_timing.int_times_table
      ~det_timing.pix_timing_map
      ~det_timing.pixel_noise
      ~det_timing.times_to_dict
      ~det_timing.to_dict
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~det_timing.chsize
      ~det_timing.mask_act
      ~det_timing.mask_channels
      ~det_timing.mask_ref
      ~det_timing.nff
      ~det_timing.nout
      ~det_timing.ref_info
      ~det_timing.time_exp
      ~det_timing.time_frame
      ~det_timing.time_group
      ~det_timing.time_int
      ~det_timing.time_int_eff
      ~det_timing.time_ramp
      ~det_timing.time_ramp_eff
      ~det_timing.time_row_reset
      ~det_timing.time_total
      ~det_timing.time_total_int1
      ~det_timing.time_total_int2
      ~det_timing.times_group_avg
      ~det_timing.wind_mode
      ~det_timing.x0
      ~det_timing.xpix
      ~det_timing.y0
      ~det_timing.ypix
   
   